@@ -271,33 +271,48 @@ static void test_gserialized2_is_empty(void)
 {
 	int i = 0;
 	struct gserialized_empty_cases {
-		const char* wkt;
+		int ishex;
+		const char* txt;
 		int isempty;
 	};
 
 	struct gserialized_empty_cases cases[] = {
-		{ "POINT EMPTY", 1 },
-		{ "POINT(1 1)", 0 },
-		{ "LINESTRING EMPTY", 1 },
-		{ "MULTILINESTRING EMPTY", 1 },
-		{ "MULTILINESTRING(EMPTY)", 1 },
-		{ "MULTILINESTRING(EMPTY,EMPTY)", 1 },
-		{ "MULTILINESTRING(EMPTY,(0 0,1 1))", 0 },
-		{ "MULTILINESTRING((0 0,1 1),EMPTY)", 0 },
-		{ "MULTILINESTRING(EMPTY,(0 0,1 1),EMPTY)", 0 },
-		{ "MULTILINESTRING(EMPTY,EMPTY,EMPTY)", 1 },
-		{ "GEOMETRYCOLLECTION(POINT EMPTY,MULTILINESTRING(EMPTY,EMPTY,EMPTY))", 1 },
-		{ "GEOMETRYCOLLECTION(POINT EMPTY,MULTILINESTRING(EMPTY),POINT(1 1))", 0 },
-		{ "GEOMETRYCOLLECTION(POINT EMPTY,MULTILINESTRING(EMPTY, (0 0)),POINT EMPTY)", 0 },
-		{ "GEOMETRYCOLLECTION(POLYGON EMPTY,POINT EMPTY,MULTILINESTRING(EMPTY,EMPTY),POINT EMPTY)", 1 },
-		{ "GEOMETRYCOLLECTION(POLYGON EMPTY,GEOMETRYCOLLECTION(POINT EMPTY),MULTILINESTRING(EMPTY,EMPTY),POINT EMPTY)", 1 },
-		{ NULL, 0 }
+		{ 0, "POINT EMPTY", 1 },
+		{ 0, "POINT(1 1)", 0 },
+		{ 0, "LINESTRING EMPTY", 1 },
+		{ 0, "MULTILINESTRING EMPTY", 1 },
+		{ 0, "MULTILINESTRING(EMPTY)", 1 },
+		{ 0, "MULTILINESTRING(EMPTY,EMPTY)", 1 },
+		{ 0, "MULTILINESTRING(EMPTY,(0 0,1 1))", 0 },
+		{ 0, "MULTILINESTRING((0 0,1 1),EMPTY)", 0 },
+		{ 0, "MULTILINESTRING(EMPTY,(0 0,1 1),EMPTY)", 0 },
+		{ 0, "MULTILINESTRING(EMPTY,EMPTY,EMPTY)", 1 },
+		{ 0, "MULTIPOLYGON (((9 9, 9 1, 1 1, 2 4, 7 7, 9 9)), EMPTY)", 0 },
+		{ 0, "GEOMETRYCOLLECTION(POINT EMPTY,MULTILINESTRING(EMPTY,EMPTY,EMPTY))", 1 },
+		{ 0, "GEOMETRYCOLLECTION(POINT EMPTY,MULTILINESTRING(EMPTY),POINT(1 1))", 0 },
+		{ 0, "GEOMETRYCOLLECTION(POINT EMPTY,MULTILINESTRING(EMPTY, (0 0)),POINT EMPTY)", 0 },
+		{ 0, "GEOMETRYCOLLECTION(POLYGON EMPTY,POINT EMPTY,MULTILINESTRING(EMPTY,EMPTY),POINT EMPTY)", 1 },
+		{ 0, "GEOMETRYCOLLECTION(POLYGON EMPTY,GEOMETRYCOLLECTION(POINT EMPTY),MULTILINESTRING(EMPTY,EMPTY),POINT EMPTY)", 1 },
+		{ 1, "0101000000000000000000F87F000000000000F87F", 1 }, /* POINT EMPTY */
+		{ 1, "010200000000000000", 1 }, /* LINESTRING EMPTY */
+		{ 1, "010400000000000000", 1 }, /* MULTIPOINT EMPTY */
+		{ 1, "0105000000020000000102000000020000000000000000000000000000000000000000000000000000000000000000000000010200000000000000", 0 }, /* MULTILINESTRING ((0 0, 0 0), EMPTY) */
+		{ 1, "0105000000020000000102000000000000000102000000020000000000000000000000000000000000000000000000000000000000000000000000", 0 }, /* MULTILINESTRING (EMPTY,(0 0, 0 0)) */
+		{ 1, "010300000000000000", 1 }, /* POLYGON EMPTY */
+		{ 1, "01030000000100000000000000", 1 }, /* POLYGON(EMPTY) */
+		{ 1, "010300000002000000000000000100000000000000000000000000000000000000", 0 }, /* POLYGON(EMPTY, (0 0)) */
+		{ 1, "0107000000030000000102000000000000000103000000020000000000000000000000010200000000000000", 1}, /* GEOMETRYCOLLECTION(LINESTRING EMPTY, POLYGON(EMPTY, EMPTY), LINESTRING EMPTY) */
+		{ 1, NULL, 0 }
 	};
 
-	while( cases[i].wkt )
+	while( cases[i].txt )
 	{
-		// i = 11;
-		LWGEOM *lw = lwgeom_from_wkt(cases[i].wkt, LW_PARSER_CHECK_NONE);
+		LWGEOM *lw = NULL;
+		if (cases[i].ishex)
+			lw = lwgeom_from_hexwkb(cases[i].txt, LW_PARSER_CHECK_NONE);
+		else
+			lw = lwgeom_from_wkt(cases[i].txt, LW_PARSER_CHECK_NONE);
+
 		GSERIALIZED *g = gserialized2_from_lwgeom(lw, 0);
 		int ie = gserialized2_is_empty(g);
 		// printf("%s: we say %d, they say %d\n", cases[i].wkt, cases[i].isempty, ie);
@@ -309,7 +324,6 @@ static void test_gserialized2_is_empty(void)
 }
 
 
-
 static void test_on_gser2_lwgeom_count_vertices(void)
 {
 	LWGEOM *lwgeom;
