@@ -578,6 +578,14 @@ static LWPOLY* lwpoly_from_wkb_state(wkb_parse_state *s)
 			return NULL;
 		}
 
+		/* Skip zero-member rings, they add nothing */
+		if ( pa->npoints == 0)
+		{
+			LWDEBUGF(2, "Skipping empty ring [%d]", i);
+			ptarray_free(pa);
+			continue;
+		}
+
 		/* Add ring to polygon */
 		if ( lwpoly_add_ring(poly, pa) == LW_FAILURE )
 		{
