@@ -5,9 +5,6 @@
 
 #ifdef HAVE_LIBPROTOBUF
 #include <protobuf-c/protobuf-c.h>
-#endif
-
-#ifdef HAVE_WAGYU
 #include "lwgeom_wagyu.h"
 #endif
 
@@ -26,9 +23,9 @@ Datum postgis_libprotobuf_version(PG_FUNCTION_ARGS)
 PG_FUNCTION_INFO_V1(postgis_wagyu_version);
 Datum postgis_wagyu_version(PG_FUNCTION_ARGS)
 {
-#ifndef HAVE_WAGYU
+#ifndef HAVE_LIBPROTOBUF
 	PG_RETURN_NULL();
-#else /* HAVE_WAGYU  */
+#else /* HAVE_LIBPROTOBUF  */
 	const char *ver = libwagyu_version();
 	text *result = cstring_to_text(ver);
 	PG_RETURN_POINTER(result);
