@@ -499,12 +499,6 @@ rt_raster_generate_new_band(
     int oldnumbands = 0;
     int numbands = 0;
     void * mem = NULL;
-    int32_t checkvalint = 0;
-    uint32_t checkvaluint = 0;
-    double checkvaldouble = 0;
-    float checkvalfloat = 0;
-    int i;
-
 
     assert(NULL != raster);
 
@@ -527,143 +521,27 @@ rt_raster_generate_new_band(
         return -1;
     }
 
-    if (FLT_EQ(initialvalue, 0.0))
-        memset(mem, 0, datasize);
-    else {
-        switch (pixtype)
-        {
-            case PT_1BB:
-            {
-                uint8_t *ptr = mem;
-                uint8_t clamped_initval = rt_util_clamp_to_1BB(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_2BUI:
-            {
-                uint8_t *ptr = mem;
-                uint8_t clamped_initval = rt_util_clamp_to_2BUI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_4BUI:
-            {
-                uint8_t *ptr = mem;
-                uint8_t clamped_initval = rt_util_clamp_to_4BUI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_8BSI:
-            {
-                int8_t *ptr = mem;
-                int8_t clamped_initval = rt_util_clamp_to_8BSI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_8BUI:
-            {
-                uint8_t *ptr = mem;
-                uint8_t clamped_initval = rt_util_clamp_to_8BUI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_16BSI:
-            {
-                int16_t *ptr = mem;
-                int16_t clamped_initval = rt_util_clamp_to_16BSI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_16BUI:
-            {
-                uint16_t *ptr = mem;
-                uint16_t clamped_initval = rt_util_clamp_to_16BUI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_32BSI:
-            {
-                int32_t *ptr = mem;
-                int32_t clamped_initval = rt_util_clamp_to_32BSI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalint = ptr[0];
-                break;
-            }
-            case PT_32BUI:
-            {
-                uint32_t *ptr = mem;
-                uint32_t clamped_initval = rt_util_clamp_to_32BUI(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvaluint = ptr[0];
-                break;
-            }
-            case PT_32BF:
-            {
-                float *ptr = mem;
-                float clamped_initval = rt_util_clamp_to_32F(initialvalue);
-                for (i = 0; i < numval; i++)
-                    ptr[i] = clamped_initval;
-                checkvalfloat = ptr[0];
-                break;
-            }
-            case PT_64BF:
-            {
-                double *ptr = mem;
-                for (i = 0; i < numval; i++)
-                    ptr[i] = initialvalue;
-                checkvaldouble = ptr[0];
-                break;
-            }
-            default:
-            {
-                rterror("rt_raster_generate_new_band: Unknown pixeltype %d", pixtype);
-                rtdealloc(mem);
-                return -1;
-            }
-        }
-    }
-
-    /* Overflow checking */
-    rt_util_dbl_trunc_warning(
-			initialvalue,
-			checkvalint, checkvaluint,
-			checkvalfloat, checkvaldouble,
-			pixtype
-		);
-
     band = rt_band_new_inline(width, height, pixtype, hasnodata, nodatavalue, mem);
     if (! band) {
         rterror("rt_raster_generate_new_band: Could not add band to raster. Aborting");
         rtdealloc(mem);
         return -1;
     }
-		rt_band_set_ownsdata_flag(band, 1); /* we DO own this data!!! */
-    index = rt_raster_add_band(raster, band, index);
-    numbands = rt_raster_get_num_bands(raster);
-    if (numbands == oldnumbands || index == -1) {
-        rterror("rt_raster_generate_new_band: Could not add band to raster. Aborting");
-        rt_band_destroy(band);
-    }
 
-		/* set isnodata if hasnodata = TRUE and initial value = nodatavalue */
-		if (hasnodata && FLT_EQ(initialvalue, nodatavalue))
-			rt_band_set_isnodata_flag(band, 1);
+	rt_band_init_value(band, initialvalue);
+
+	rt_band_set_ownsdata_flag(band, 1); /* we DO own this data!!! */
+	index = rt_raster_add_band(raster, band, index);
+	numbands = rt_raster_get_num_bands(raster);
+	if (numbands == oldnumbands || index == -1) {
+		rterror("rt_raster_generate_new_band: Could not add band to raster. Aborting");
+		rt_band_destroy(band);
+		return -1;
+	}
+
+	/* set isnodata if hasnodata = TRUE and initial value = nodatavalue */
+	if (hasnodata && FLT_EQ(initialvalue, nodatavalue))
+		rt_band_set_isnodata_flag(band, 1);
 
     return index;
 }
@@ -2080,7 +1958,9 @@ rt_raster_to_gdal_mem(
 		/*
 			For all pixel types other than PT_8BSI, set pointer to start of data
 		*/
+#if POSTGIS_GDAL_VERSION < 30700
 		if (pt != PT_8BSI) {
+#endif
 			pVoid = rt_band_get_data(rtband);
 			RASTER_DEBUGF(4, "Band data is at pos %p", pVoid);
 
@@ -2111,12 +1991,12 @@ rt_raster_to_gdal_mem(
 				GDALClose(ds);
 				return 0;
 			}
-		}
+#if POSTGIS_GDAL_VERSION < 30700
 		/*
-			PT_8BSI is special as GDAL has no equivalent pixel type.
+			PT_8BSI is special as GDAL (prior to 3.7) has no equivalent pixel type.
 			Must convert 8BSI to 16BSI so create basic band
 		*/
-		else {
+		} else {
 			/* add band */
 			if (GDALAddBand(ds, gdal_pt, NULL) == CE_Failure) {
 				rterror("rt_raster_to_gdal_mem: Could not add GDAL raster band");
@@ -2126,6 +2006,7 @@ rt_raster_to_gdal_mem(
 				return 0;
 			}
 		}
+#endif
 
 		/* check band count */
 		if (GDALGetRasterCount(ds) != i + 1) {
@@ -2147,6 +2028,8 @@ rt_raster_to_gdal_mem(
 			return 0;
 		}
 
+#if POSTGIS_GDAL_VERSION < 30700
+
 		/* PT_8BSI requires manual setting of pixels */
 		if (pt == PT_8BSI) {
 			uint32_t nXBlocks, nYBlocks;
@@ -2242,6 +2125,7 @@ rt_raster_to_gdal_mem(
 
 			rtdealloc(values);
 		}
+#endif
 
 		/* Add nodata value for band */
 		if (rt_band_get_hasnodata_flag(rtband) != FALSE && excludeNodataValues[i]) {
@@ -2402,7 +2286,7 @@ rt_raster_from_gdal_dataset(GDALDatasetH ds) {
 
 		/* pixtype */
 		gdpixtype = GDALGetRasterDataType(gdband);
-		RASTER_DEBUGF(4, "gdpixtype, size = %s, %d", GDALGetDataTypeName(gdpixtype), GDALGetDataTypeSize(gdpixtype) / 8);
+		RASTER_DEBUGF(4, "gdpixtype, size = %s, %d", GDALGetDataTypeName(gdpixtype), GDALGetDataTypeSizeBytes(gdpixtype));
 		pt = rt_util_gdal_datatype_to_pixtype(gdpixtype);
 		if (pt == PT_END) {
 			rterror("rt_raster_from_gdal_dataset: Unknown pixel type for GDAL band");
@@ -2825,7 +2709,7 @@ rt_raster_gdal_rasterize(
 		_dim[1] == 0
 	) {
 
-#if POSTGIS_GDAL_VERSION > 18
+#if POSTGIS_GDAL_VERSION > 10800
 
 		RASTER_DEBUG(3, "Adjusting extent for GDAL > 1.8 by half the scale on X-axis");
 		extent.MinX -= (_scale[0] / 2.);
