@@ -1,6 +1,6 @@
 set client_min_messages to ERROR;
 
-\i ../load_topology.sql
+\i :top_builddir/topology/test/load_topology.sql
 
 -- Test bogus calls
 SELECT 'non-existent-topo', topology.GetRingEdges('non-existent', 1);
