@@ -1,4 +1,5 @@
 set client_min_messages to WARNING;
+set search_path to public,pg_catalog;
 
 \i :top_builddir/topology/test/load_topology.sql
 \i ../load_features.sql
@@ -74,7 +75,7 @@ WITH deleted AS (
   DELETE FROM features.city_streets WHERE feature_name IN ( 'R1' )
   RETURNING feature
 ), clear AS (
-  SELECT clearTopoGeom(feature) FROM deleted
+  SELECT topology.clearTopoGeom(feature) FROM deleted
 ) SELECT NULL FROM clear;
 
 --set client_min_messages to DEBUG;
@@ -88,7 +89,7 @@ WITH deleted AS (
   DELETE FROM features.traffic_signs WHERE feature_name IN ( 'S3' )
   RETURNING feature
 ), clear AS (
-  SELECT clearTopoGeom(feature) FROM deleted
+  SELECT topology.clearTopoGeom(feature) FROM deleted
 ) SELECT NULL FROM clear;
 
 --set client_min_messages to DEBUG;
@@ -102,7 +103,7 @@ WITH deleted AS (
   DELETE FROM features.traffic_signs WHERE feature_name IN ( 'S4' )
   RETURNING feature
 ), clear AS (
-  SELECT clearTopoGeom(feature) FROM deleted
+  SELECT topology.clearTopoGeom(feature) FROM deleted
 ) SELECT NULL FROM clear;
 
 --set client_min_messages to DEBUG;
@@ -124,16 +125,16 @@ start_point AS (
   FROM deleted
 ),
 clear AS (
-  SELECT sp, clearTopoGeom(feature)
+  SELECT sp, topology.clearTopoGeom(feature)
   FROM start_point
 )
 INSERT INTO features.traffic_signs ( feature_name, feature )
 SELECT
   'TS1',
-  toTopoGeom(
+  topology.toTopoGeom(
     sp,
     'city_data',
-    layer_id(findLayer('features', 'traffic_signs', 'feature')),
+    layer_id(topology.findLayer('features', 'traffic_signs', 'feature')),
     0
   )
 FROM clear;
@@ -174,12 +175,12 @@ WITH node AS (
   FROM features.traffic_signs WHERE feature_name = 'S1'
 ),
 triangle_right AS (
-  SELECT TopoGeo_addLineString( 'city_data',
+  SELECT topology.TopoGeo_addLineString( 'city_data',
     features.triangle(g, 4, 4)
   ) FROM node
 ),
 triangle_left AS (
-  SELECT TopoGeo_addLineString( 'city_data',
+  SELECT topology.TopoGeo_addLineString( 'city_data',
     features.triangle(g, -4, 4)
   ) FROM node
 )
@@ -194,7 +195,7 @@ WITH deleted AS (
   RETURNING feature
 ),
 clear AS (
-  SELECT clearTopoGeom(feature)
+  SELECT topology.clearTopoGeom(feature)
   FROM deleted
 )
 SELECT NULL FROM clear;
@@ -207,7 +208,7 @@ SELECT 't6', 'invalidity', * FROM topology.ValidateTopology('city_data');
 
 -- See https://trac.osgeo.org/postgis/ticket/5289
 SELECT NULL FROM (
-  SELECT toTopoGeom(
+  SELECT topology.toTopoGeom(
     ST_MakeLine(
       ST_EndPoint( ST_GeometryN(feature,1) ),
       ST_StartPoint( ST_GeometryN(feature,1) )
@@ -230,7 +231,7 @@ SELECT '#5289', 'invalidity', * FROM topology.ValidateTopology('city_data');
 -- being required as endpoint of closed edge 2) while
 -- edges themselves would still be both used by R4 feature.
 UPDATE features.city_streets
-SET feature = TopoGeom_addElement(feature, ARRAY[2, 2])
+SET feature = topology.TopoGeom_addElement(feature, ARRAY[2, 2])
 WHERE feature_name = 'R4';
 UPDATE features.city_streets SET geom = feature::geometry
 WHERE feature_name = 'R4';
@@ -243,6 +244,6 @@ SELECT '#5303', 'invalidity', * FROM topology.ValidateTopology('city_data');
 -- Cleanup
 --
 
-SELECT NULL FROM DropTopology('city_data');
+SELECT NULL FROM topology.DropTopology('city_data');
 DROP SCHEMA features CASCADE;
-
+RESET search_path;
